PDFQuote class

Represents a quote in the PDF

Constructors

PDFQuote({required String text, required int pageNumber, Map<String, dynamic>? location})

Properties

hashCode → int
The hash code for this object.
no setterinherited
location → Map<String, dynamic>?
Optional location information for the quote
final
pageNumber → int
The page number where the quote appears (1-based)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
The text content of the quote
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited